Package 'rk.bayesian'

Title: An RKWard plugin for Psychology/Social Sciences (Bayesian Suite). Features 'Jamovi-style' output with Bayes Factors, Posterior Effect Sizes, Descriptives, and Plots.
Description: An RKWard plugin for Psychology/Social Sciences (Bayesian Suite). Features 'Jamovi-style' output with Bayes Factors, Posterior Effect Sizes, Descriptives, and Plots.
Authors: Alfonso Cano
Maintainer: Alfonso Cano <[email protected]>
License: GPL (>= 3)
Version: 0.0.2
Built: 2026-06-05 06:55:35 UTC
Source: https://github.com/AlfCano/rk.bayesian

Help Index